package xyz.mcutils;

import lombok.SneakyThrows;
import org.junit.jupiter.api.Test;
import xyz.mcutils.exception.ErrorResponse;
import xyz.mcutils.models.cache.CachedPlayer;
import xyz.mcutils.models.player.CachedPlayerSkinPart;
import xyz.mcutils.models.cache.CachedUsernameToUuid;
import xyz.mcutils.models.player.Skin;

public class PlayerTests {

    private final String testPlayerUuid = "eeab5f8a-18dd-4d58-af78-2b3c4543da48";
    private final String testPlayer = "ImFascinated";
    private final String testInvalidPlayer = "invalidplayeromgyeswow";

    @Test
    @SneakyThrows
    public void ensurePlayerLookupUuidSuccess() {
        CachedPlayer player = McUtilsAPI.getPlayer(testPlayerUuid);
        assert player.getUsername().equals(testPlayer);
    }

    @Test
    @SneakyThrows
    public void ensurePlayerLookupUuidFailure() {
        try {
            McUtilsAPI.getPlayer(testInvalidPlayer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 404;
        }
    }

    @Test
    @SneakyThrows
    public void ensurePlayerLookupUsernameSuccess() {
        CachedPlayer player = McUtilsAPI.getPlayer(testPlayer);
        assert player.getUsername().equals(testPlayer);
    }

    @Test
    @SneakyThrows
    public void ensurePlayerLookupUsernameFailure() {
        try {
            McUtilsAPI.getPlayer(testInvalidPlayer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 404;
        }
    }

    @Test
    @SneakyThrows
    public void ensurePlayerUsernameToUuidLookupSuccess() {
        CachedUsernameToUuid player = McUtilsAPI.getUsernameToUuid(testPlayer);
        assert player.getUsername().equals(testPlayer);
        assert player.getUniqueId().toString().equals(testPlayerUuid);
    }

    @Test
    @SneakyThrows
    public void ensurePlayerUsernameToUuidLookupFailure() {
        try {
            McUtilsAPI.getUsernameToUuid(testInvalidPlayer);
        } catch (ErrorResponse ex) {
            assert ex.getCode() == 404;
        }
    }

    @Test
    @SneakyThrows
    public void ensurePlayerSkinPartsLookupSuccess() {
        for (Skin.SkinPart part : Skin.SkinPart.values()) {
            CachedPlayerSkinPart partBytes = McUtilsAPI.getPlayerSkinPart(part, testPlayer);
            assert partBytes.getPartBytes() != null;
        }
    }
}
